/************************************************************************************
DeviceControl RT-Component
Copyright (c) 2010, Kyoto Uni.
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD lisence.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

/***********************************************************************************/
/*!
*	@file Dacs2600.h
*	@brief Class for Dacs2600
*	@author kazuyuki kon@ Kyoto-u
*/
/***********************************************************************************/

#include "Dacs2600.h"

/***********************************************************************************/
//Default constructor
/***********************************************************************************/
Dacs2600::Dacs2600()
{
	//dataset
	baudrate[0] = 4800;
	baudrate[1] = 9600;
	baudrate[2] = 19200;
	baudrate[3] = 38400;
	baudrate[4] = 57600;
	baudrate[5] = 115200;
	baudrate[6] = 230400;
	baudrate[7] = 460800;
    
	setbit[0] = 0x01;
	setbit[1] = 0x02;
	setbit[2] = 0x04;
	setbit[3] = 0x08;
	setbit[4] = 0x10;
	setbit[5] = 0x20;
	setbit[6] = 0x40;
	setbit[7] = 0x80;


	status[0]  = 2;
	command[0]    = 0x00;

	isConnect = false;
}

/***********************************************************************************/
//Denstructor
/***********************************************************************************/
Dacs2600::~Dacs2600()
{
	terminate();
}

/***********************************************************************************/
//initialize
/***********************************************************************************/
bool Dacs2600::initialize(std::string _portname)
{
	for(int i = 0;i<8;i++)
	{
		printf("Trying %d[bps]\n",baudrate[i]);

		if( initialize(_portname,baudrate[i]) )
		{
			return true;
		}
	}
	return false;
}

/***********************************************************************************/
//initialize
/***********************************************************************************/
bool Dacs2600::initialize(std::string _portname,int _baudrate)
{
	serial.setPortName( _portname );
	serial.setBaudrate( _baudrate );
	serial.setFlowControl( serial_port_base::flow_control::hardware );

	if( serial.openPort( true ) )
	{
		isConnect = true;
		return true;
	}
	else return false;
}

/***********************************************************************************/
//terminate serial communication
/***********************************************************************************/
void Dacs2600::terminate(void)
{	
	if( getConnectionStatus() )
	{
		serial.closePort();
		isConnect = false;
	}
}

/***********************************************************************************/
//Get connection status
/***********************************************************************************/
inline bool Dacs2600::getConnectionStatus()
{
	return isConnect;
}

/***********************************************************************************/
//
/***********************************************************************************/
bool Dacs2600::update(void)
{
    if( getConnectionStatus() )
	{
		
		serial.write(command,1);
		while( serial.getReadDataSize() > 0)
		{
			serial.read(status,1);
		}	
		return true;
	}
	return false;
}

/***********************************************************************************/
//
/***********************************************************************************/
bool Dacs2600::getEMOStatus(void)
{
	bool mode = ((unsigned char)status[0]>>(EMO)) & 0x01;    
	return mode;
}

/***********************************************************************************/
//one light
/***********************************************************************************/
void Dacs2600::setLightMode(int mode)
{
	command[0] = 0x00;
       // printf(" mode :: %d\n",mode);
	if(mode ==1){//green
		command[0] = setbit[LIGHT_GREEN];
	}
	else if(mode ==2){//orange
		command[0] = setbit[LIGHT_ORANGE];	
	}
	else if(mode ==3){//red
		command[0] = setbit[LIGHT_RED];	
	}
	else
	{
		command[0] = 0x00;
	}
}

/***********************************************************************************/
//one (two, three) at the same time
/***********************************************************************************/
void Dacs2600::setLightMode2(int mode)
{
	//command = 0x00;
       // printf(" mode :: %d\n",mode);
	if(mode ==1){//green
		command[0] |= setbit[LIGHT_GREEN];
	}
	else if(mode ==2){//orange
		command[0] |= setbit[LIGHT_ORANGE];	
	}
	else if(mode ==3){//red
		command[0] |= setbit[LIGHT_RED];	
	}else{
		command[0] = 0x00;
	}
}


